require "import"
import "android.widget.*"
import "android.view.*"
import "android.app.*"
import "android.media.*"
import "java.io.*"

local activity = activity
local mediaRecorder
local recordedFile
local isRecording = false

function onCreate(savedInstanceState)
    activity.setTitle("MP3 Voice Recorder")
    local layout = LinearLayout(activity)
    layout.setOrientation(1)

    local recordButton = Button(activity)
    recordButton.setText("Record")
    recordButton.setOnClickListener{
        onClick = function(v)
            if not isRecording then
                startRecording()
            else
                pauseRecording()
            end
        end
    }
    layout.addView(recordButton)

    local resumeButton = Button(activity)
    resumeButton.setText("Resume")
    resumeButton.setOnClickListener{
        onClick = function(v)
            resumeRecording()
        end
    }
    layout.addView(resumeButton)

    local stopButton = Button(activity)
    stopButton.setText("Stop")
    stopButton.setOnClickListener{
        onClick = function(v)
            stopRecording()
        end
    }
    layout.addView(stopButton)

    local playButton = Button(activity)
    playButton.setText("Play")
    playButton.setOnClickListener{
        onClick = function(v)
            playRecording()
        end
    }
    layout.addView(playButton)

    activity.setContentView(layout)
end

function startRecording()
    if mediaRecorder == nil then
        mediaRecorder = MediaRecorder()
        mediaRecorder.setAudioSource(MediaRecorder.AudioSource.MIC)
        mediaRecorder.setOutputFormat(MediaRecorder.OutputFormat.MPEG_4)
        mediaRecorder.setAudioEncoder(MediaRecorder.AudioEncoder.AAC)
        mediaRecorder.setAudioEncodingBitRate(320000)
        local fileName = os.date("%Y%m%d_%H%M%S") .. ".mp3"
        local filePath = activity.getExternalFilesDir(nil).getAbsolutePath() .. "/" .. fileName
        mediaRecorder.setOutputFile(filePath)
        mediaRecorder.prepare()
        mediaRecorder.start()
        recordedFile = filePath
        isRecording = true
    end
end

function pauseRecording()
    if mediaRecorder ~= nil then
        mediaRecorder.pause()
        isRecording = false
    end
end

function resumeRecording()
    if mediaRecorder ~= nil then
        mediaRecorder.resume()
        isRecording = true
    end
end

function stopRecording()
    if mediaRecorder ~= nil then
        mediaRecorder.stop()
        mediaRecorder.release()
        mediaRecorder = nil
        isRecording = false
        Toast.makeText(activity, "Recording saved to: " .. recordedFile, Toast.LENGTH_SHORT).show()
    end
end

function playRecording()
    if recordedFile ~= nil then
        local mediaPlayer = MediaPlayer()
        mediaPlayer.setDataSource(recordedFile)
        mediaPlayer.prepare()
        mediaPlayer.start()
    end
end